joincontext

package
v0.0.101 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 6, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(ctx1, ctx2 context.Context) (context.Context, context.CancelFunc)

New returns a new context that inherits cancellation and deadlines from both ctx1 and ctx2. The returned context is done when either parent is done or when the returned cancel function is called.

Values are looked up in ctx1 first, falling back to ctx2.

Types

This section is empty.

Jump to